@@ -5,7 +5,7 @@ from pyspark.ml import Transformer
 from spark_pipeline_framework.transformers.framework_transformer.v1.framework_transformer import (
     FrameworkTransformer,
 )
-from spark_pipeline_framework.utilities.flattener import flatten
+from spark_pipeline_framework.utilities.flattener.flattener import flatten
 
 
 def create_steps(
